@@ -1,9 +1,9 @@
 import uuid
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 
 @dataclass
 class Equipment:
 
     id: uuid.UUID
     name: str
-    active: bool
+    active: bool = field(default=True)
