@@ -1,5 +1,8 @@
 import uuid
 
+"""
+EQUIPMENT_TYPES maps equipment class names from the mercury pricing db to equipment.id values in freight-hub.
+"""
 EQUIPMENT_TYPES = {
   "VAN": "b738a0d4-a03d-4302-8f57-2aa1f3eb2f9b",
   "REEFER": "836284b0-f1ae-4f78-83e6-93f81b4c22c9",
@@ -11,5 +14,6 @@ EQUIPMENT_TYPES = {
   "TANKER": "689e53ba-f44f-4702-8db4-9f706018fc56",
   "RGN": "86bdf40d-539f-4e70-90a2-c5471f2604c3",
   "CONTAINER": "42a8e1cf-c85b-4357-b229-a09c163b72f7",
+  "HIGH_CUBE_CONTAINER": "42a8e1cf-c85b-4357-b229-a09c163b72f7",
   "POWER ONLY": "e9ced401-93d9-4bc9-9342-d020481133dc"
 }
